/*
Ory Hydra API

Documentation for all of Ory Hydra's APIs. 

API version: v2.2.0
Contact: hi@ory.sh
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package client

import (
	"encoding/json"
	"fmt"
)

// checks if the OidcConfiguration type satisfies the MappedNullable interface at compile time
var _ MappedNullable = &OidcConfiguration{}

// OidcConfiguration Includes links to several endpoints (for example `/oauth2/token`) and exposes information on supported signature algorithms among others.
type OidcConfiguration struct {
	// OAuth 2.0 Authorization Endpoint URL
	AuthorizationEndpoint string `json:"authorization_endpoint"`
	// OpenID Connect Back-Channel Logout Session Required  Boolean value specifying whether the OP can pass a sid (session ID) Claim in the Logout Token to identify the RP session with the OP. If supported, the sid Claim is also included in ID Tokens issued by the OP
	BackchannelLogoutSessionSupported *bool `json:"backchannel_logout_session_supported,omitempty"`
	// OpenID Connect Back-Channel Logout Supported  Boolean value specifying whether the OP supports back-channel logout, with true indicating support.
	BackchannelLogoutSupported *bool `json:"backchannel_logout_supported,omitempty"`
	// OpenID Connect Claims Parameter Parameter Supported  Boolean value specifying whether the OP supports use of the claims parameter, with true indicating support.
	ClaimsParameterSupported *bool `json:"claims_parameter_supported,omitempty"`
	// OpenID Connect Supported Claims  JSON array containing a list of the Claim Names of the Claims that the OpenID Provider MAY be able to supply values for. Note that for privacy or other reasons, this might not be an exhaustive list.
	ClaimsSupported []string `json:"claims_supported,omitempty"`
	// OAuth 2.0 PKCE Supported Code Challenge Methods  JSON array containing a list of Proof Key for Code Exchange (PKCE) [RFC7636] code challenge methods supported by this authorization server.
	CodeChallengeMethodsSupported []string `json:"code_challenge_methods_supported,omitempty"`
	// OpenID Connect Verifiable Credentials Endpoint  Contains the URL of the Verifiable Credentials Endpoint.
	CredentialsEndpointDraft00 *string `json:"credentials_endpoint_draft_00,omitempty"`
	// OpenID Connect Verifiable Credentials Supported  JSON array containing a list of the Verifiable Credentials supported by this authorization server.
	CredentialsSupportedDraft00 []CredentialSupportedDraft00 `json:"credentials_supported_draft_00,omitempty"`
	// OpenID Connect End-Session Endpoint  URL at the OP to which an RP can perform a redirect to request that the End-User be logged out at the OP.
	EndSessionEndpoint *string `json:"end_session_endpoint,omitempty"`
	// OpenID Connect Front-Channel Logout Session Required  Boolean value specifying whether the OP can pass iss (issuer) and sid (session ID) query parameters to identify the RP session with the OP when the frontchannel_logout_uri is used. If supported, the sid Claim is also included in ID Tokens issued by the OP.
	FrontchannelLogoutSessionSupported *bool `json:"frontchannel_logout_session_supported,omitempty"`
	// OpenID Connect Front-Channel Logout Supported  Boolean value specifying whether the OP supports HTTP-based logout, with true indicating support.
	FrontchannelLogoutSupported *bool `json:"frontchannel_logout_supported,omitempty"`
	// OAuth 2.0 Supported Grant Types  JSON array containing a list of the OAuth 2.0 Grant Type values that this OP supports.
	GrantTypesSupported []string `json:"grant_types_supported,omitempty"`
	// OpenID Connect Default ID Token Signing Algorithms  Algorithm used to sign OpenID Connect ID Tokens.
	IdTokenSignedResponseAlg []string `json:"id_token_signed_response_alg"`
	// OpenID Connect Supported ID Token Signing Algorithms  JSON array containing a list of the JWS signing algorithms (alg values) supported by the OP for the ID Token to encode the Claims in a JWT.
	IdTokenSigningAlgValuesSupported []string `json:"id_token_signing_alg_values_supported"`
	// OpenID Connect Issuer URL  An URL using the https scheme with no query or fragment component that the OP asserts as its IssuerURL Identifier. If IssuerURL discovery is supported , this value MUST be identical to the issuer value returned by WebFinger. This also MUST be identical to the iss Claim value in ID Tokens issued from this IssuerURL.
	Issuer string `json:"issuer"`
	// OpenID Connect Well-Known JSON Web Keys URL  URL of the OP's JSON Web Key Set [JWK] document. This contains the signing key(s) the RP uses to validate signatures from the OP. The JWK Set MAY also contain the Server's encryption key(s), which are used by RPs to encrypt requests to the Server. When both signing and encryption keys are made available, a use (Key Use) parameter value is REQUIRED for all keys in the referenced JWK Set to indicate each key's intended usage. Although some algorithms allow the same key to be used for both signatures and encryption, doing so is NOT RECOMMENDED, as it is less secure. The JWK x5c parameter MAY be used to provide X.509 representations of keys provided. When used, the bare key values MUST still be present and MUST match those in the certificate.
	JwksUri string `json:"jwks_uri"`
	// OpenID Connect Dynamic Client Registration Endpoint URL
	RegistrationEndpoint *string `json:"registration_endpoint,omitempty"`
	// OpenID Connect Supported Request Object Signing Algorithms  JSON array containing a list of the JWS signing algorithms (alg values) supported by the OP for Request Objects, which are described in Section 6.1 of OpenID Connect Core 1.0 [OpenID.Core]. These algorithms are used both when the Request Object is passed by value (using the request parameter) and when it is passed by reference (using the request_uri parameter).
	RequestObjectSigningAlgValuesSupported []string `json:"request_object_signing_alg_values_supported,omitempty"`
	// OpenID Connect Request Parameter Supported  Boolean value specifying whether the OP supports use of the request parameter, with true indicating support.
	RequestParameterSupported *bool `json:"request_parameter_supported,omitempty"`
	// OpenID Connect Request URI Parameter Supported  Boolean value specifying whether the OP supports use of the request_uri parameter, with true indicating support.
	RequestUriParameterSupported *bool `json:"request_uri_parameter_supported,omitempty"`
	// OpenID Connect Requires Request URI Registration  Boolean value specifying whether the OP requires any request_uri values used to be pre-registered using the request_uris registration parameter.
	RequireRequestUriRegistration *bool `json:"require_request_uri_registration,omitempty"`
	// OAuth 2.0 Supported Response Modes  JSON array containing a list of the OAuth 2.0 response_mode values that this OP supports.
	ResponseModesSupported []string `json:"response_modes_supported,omitempty"`
	// OAuth 2.0 Supported Response Types  JSON array containing a list of the OAuth 2.0 response_type values that this OP supports. Dynamic OpenID Providers MUST support the code, id_token, and the token id_token Response Type values.
	ResponseTypesSupported []string `json:"response_types_supported"`
	// OAuth 2.0 Token Revocation URL  URL of the authorization server's OAuth 2.0 revocation endpoint.
	RevocationEndpoint *string `json:"revocation_endpoint,omitempty"`
	// OAuth 2.0 Supported Scope Values  JSON array containing a list of the OAuth 2.0 [RFC6749] scope values that this server supports. The server MUST support the openid scope value. Servers MAY choose not to advertise some supported scope values even when this parameter is used
	ScopesSupported []string `json:"scopes_supported,omitempty"`
	// OpenID Connect Supported Subject Types  JSON array containing a list of the Subject Identifier types that this OP supports. Valid types include pairwise and public.
	SubjectTypesSupported []string `json:"subject_types_supported"`
	// OAuth 2.0 Token Endpoint URL
	TokenEndpoint string `json:"token_endpoint"`
	// OAuth 2.0 Supported Client Authentication Methods  JSON array containing a list of Client Authentication methods supported by this Token Endpoint. The options are client_secret_post, client_secret_basic, client_secret_jwt, and private_key_jwt, as described in Section 9 of OpenID Connect Core 1.0
	TokenEndpointAuthMethodsSupported []string `json:"token_endpoint_auth_methods_supported,omitempty"`
	// OpenID Connect Userinfo URL  URL of the OP's UserInfo Endpoint.
	UserinfoEndpoint *string `json:"userinfo_endpoint,omitempty"`
	// OpenID Connect User Userinfo Signing Algorithm  Algorithm used to sign OpenID Connect Userinfo Responses.
	UserinfoSignedResponseAlg []string `json:"userinfo_signed_response_alg"`
	// OpenID Connect Supported Userinfo Signing Algorithm  JSON array containing a list of the JWS [JWS] signing algorithms (alg values) [JWA] supported by the UserInfo Endpoint to encode the Claims in a JWT [JWT].
	UserinfoSigningAlgValuesSupported []string `json:"userinfo_signing_alg_values_supported,omitempty"`
	AdditionalProperties map[string]interface{}
}

type _OidcConfiguration OidcConfiguration

// NewOidcConfiguration instantiates a new OidcConfiguration object
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed
func NewOidcConfiguration(authorizationEndpoint string, idTokenSignedResponseAlg []string, idTokenSigningAlgValuesSupported []string, issuer string, jwksUri string, responseTypesSupported []string, subjectTypesSupported []string, tokenEndpoint string, userinfoSignedResponseAlg []string) *OidcConfiguration {
	this := OidcConfiguration{}
	this.AuthorizationEndpoint = authorizationEndpoint
	this.IdTokenSignedResponseAlg = idTokenSignedResponseAlg
	this.IdTokenSigningAlgValuesSupported = idTokenSigningAlgValuesSupported
	this.Issuer = issuer
	this.JwksUri = jwksUri
	this.ResponseTypesSupported = responseTypesSupported
	this.SubjectTypesSupported = subjectTypesSupported
	this.TokenEndpoint = tokenEndpoint
	this.UserinfoSignedResponseAlg = userinfoSignedResponseAlg
	return &this
}

// NewOidcConfigurationWithDefaults instantiates a new OidcConfiguration object
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set
func NewOidcConfigurationWithDefaults() *OidcConfiguration {
	this := OidcConfiguration{}
	return &this
}

// GetAuthorizationEndpoint returns the AuthorizationEndpoint field value
func (o *OidcConfiguration) GetAuthorizationEndpoint() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.AuthorizationEndpoint
}

// GetAuthorizationEndpointOk returns a tuple with the AuthorizationEndpoint field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetAuthorizationEndpointOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.AuthorizationEndpoint, true
}

// SetAuthorizationEndpoint sets field value
func (o *OidcConfiguration) SetAuthorizationEndpoint(v string) {
	o.AuthorizationEndpoint = v
}

// GetBackchannelLogoutSessionSupported returns the BackchannelLogoutSessionSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetBackchannelLogoutSessionSupported() bool {
	if o == nil || IsNil(o.BackchannelLogoutSessionSupported) {
		var ret bool
		return ret
	}
	return *o.BackchannelLogoutSessionSupported
}

// GetBackchannelLogoutSessionSupportedOk returns a tuple with the BackchannelLogoutSessionSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetBackchannelLogoutSessionSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.BackchannelLogoutSessionSupported) {
		return nil, false
	}
	return o.BackchannelLogoutSessionSupported, true
}

// HasBackchannelLogoutSessionSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasBackchannelLogoutSessionSupported() bool {
	if o != nil && !IsNil(o.BackchannelLogoutSessionSupported) {
		return true
	}

	return false
}

// SetBackchannelLogoutSessionSupported gets a reference to the given bool and assigns it to the BackchannelLogoutSessionSupported field.
func (o *OidcConfiguration) SetBackchannelLogoutSessionSupported(v bool) {
	o.BackchannelLogoutSessionSupported = &v
}

// GetBackchannelLogoutSupported returns the BackchannelLogoutSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetBackchannelLogoutSupported() bool {
	if o == nil || IsNil(o.BackchannelLogoutSupported) {
		var ret bool
		return ret
	}
	return *o.BackchannelLogoutSupported
}

// GetBackchannelLogoutSupportedOk returns a tuple with the BackchannelLogoutSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetBackchannelLogoutSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.BackchannelLogoutSupported) {
		return nil, false
	}
	return o.BackchannelLogoutSupported, true
}

// HasBackchannelLogoutSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasBackchannelLogoutSupported() bool {
	if o != nil && !IsNil(o.BackchannelLogoutSupported) {
		return true
	}

	return false
}

// SetBackchannelLogoutSupported gets a reference to the given bool and assigns it to the BackchannelLogoutSupported field.
func (o *OidcConfiguration) SetBackchannelLogoutSupported(v bool) {
	o.BackchannelLogoutSupported = &v
}

// GetClaimsParameterSupported returns the ClaimsParameterSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetClaimsParameterSupported() bool {
	if o == nil || IsNil(o.ClaimsParameterSupported) {
		var ret bool
		return ret
	}
	return *o.ClaimsParameterSupported
}

// GetClaimsParameterSupportedOk returns a tuple with the ClaimsParameterSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetClaimsParameterSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.ClaimsParameterSupported) {
		return nil, false
	}
	return o.ClaimsParameterSupported, true
}

// HasClaimsParameterSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasClaimsParameterSupported() bool {
	if o != nil && !IsNil(o.ClaimsParameterSupported) {
		return true
	}

	return false
}

// SetClaimsParameterSupported gets a reference to the given bool and assigns it to the ClaimsParameterSupported field.
func (o *OidcConfiguration) SetClaimsParameterSupported(v bool) {
	o.ClaimsParameterSupported = &v
}

// GetClaimsSupported returns the ClaimsSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetClaimsSupported() []string {
	if o == nil || IsNil(o.ClaimsSupported) {
		var ret []string
		return ret
	}
	return o.ClaimsSupported
}

// GetClaimsSupportedOk returns a tuple with the ClaimsSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetClaimsSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.ClaimsSupported) {
		return nil, false
	}
	return o.ClaimsSupported, true
}

// HasClaimsSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasClaimsSupported() bool {
	if o != nil && !IsNil(o.ClaimsSupported) {
		return true
	}

	return false
}

// SetClaimsSupported gets a reference to the given []string and assigns it to the ClaimsSupported field.
func (o *OidcConfiguration) SetClaimsSupported(v []string) {
	o.ClaimsSupported = v
}

// GetCodeChallengeMethodsSupported returns the CodeChallengeMethodsSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetCodeChallengeMethodsSupported() []string {
	if o == nil || IsNil(o.CodeChallengeMethodsSupported) {
		var ret []string
		return ret
	}
	return o.CodeChallengeMethodsSupported
}

// GetCodeChallengeMethodsSupportedOk returns a tuple with the CodeChallengeMethodsSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetCodeChallengeMethodsSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.CodeChallengeMethodsSupported) {
		return nil, false
	}
	return o.CodeChallengeMethodsSupported, true
}

// HasCodeChallengeMethodsSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasCodeChallengeMethodsSupported() bool {
	if o != nil && !IsNil(o.CodeChallengeMethodsSupported) {
		return true
	}

	return false
}

// SetCodeChallengeMethodsSupported gets a reference to the given []string and assigns it to the CodeChallengeMethodsSupported field.
func (o *OidcConfiguration) SetCodeChallengeMethodsSupported(v []string) {
	o.CodeChallengeMethodsSupported = v
}

// GetCredentialsEndpointDraft00 returns the CredentialsEndpointDraft00 field value if set, zero value otherwise.
func (o *OidcConfiguration) GetCredentialsEndpointDraft00() string {
	if o == nil || IsNil(o.CredentialsEndpointDraft00) {
		var ret string
		return ret
	}
	return *o.CredentialsEndpointDraft00
}

// GetCredentialsEndpointDraft00Ok returns a tuple with the CredentialsEndpointDraft00 field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetCredentialsEndpointDraft00Ok() (*string, bool) {
	if o == nil || IsNil(o.CredentialsEndpointDraft00) {
		return nil, false
	}
	return o.CredentialsEndpointDraft00, true
}

// HasCredentialsEndpointDraft00 returns a boolean if a field has been set.
func (o *OidcConfiguration) HasCredentialsEndpointDraft00() bool {
	if o != nil && !IsNil(o.CredentialsEndpointDraft00) {
		return true
	}

	return false
}

// SetCredentialsEndpointDraft00 gets a reference to the given string and assigns it to the CredentialsEndpointDraft00 field.
func (o *OidcConfiguration) SetCredentialsEndpointDraft00(v string) {
	o.CredentialsEndpointDraft00 = &v
}

// GetCredentialsSupportedDraft00 returns the CredentialsSupportedDraft00 field value if set, zero value otherwise.
func (o *OidcConfiguration) GetCredentialsSupportedDraft00() []CredentialSupportedDraft00 {
	if o == nil || IsNil(o.CredentialsSupportedDraft00) {
		var ret []CredentialSupportedDraft00
		return ret
	}
	return o.CredentialsSupportedDraft00
}

// GetCredentialsSupportedDraft00Ok returns a tuple with the CredentialsSupportedDraft00 field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetCredentialsSupportedDraft00Ok() ([]CredentialSupportedDraft00, bool) {
	if o == nil || IsNil(o.CredentialsSupportedDraft00) {
		return nil, false
	}
	return o.CredentialsSupportedDraft00, true
}

// HasCredentialsSupportedDraft00 returns a boolean if a field has been set.
func (o *OidcConfiguration) HasCredentialsSupportedDraft00() bool {
	if o != nil && !IsNil(o.CredentialsSupportedDraft00) {
		return true
	}

	return false
}

// SetCredentialsSupportedDraft00 gets a reference to the given []CredentialSupportedDraft00 and assigns it to the CredentialsSupportedDraft00 field.
func (o *OidcConfiguration) SetCredentialsSupportedDraft00(v []CredentialSupportedDraft00) {
	o.CredentialsSupportedDraft00 = v
}

// GetEndSessionEndpoint returns the EndSessionEndpoint field value if set, zero value otherwise.
func (o *OidcConfiguration) GetEndSessionEndpoint() string {
	if o == nil || IsNil(o.EndSessionEndpoint) {
		var ret string
		return ret
	}
	return *o.EndSessionEndpoint
}

// GetEndSessionEndpointOk returns a tuple with the EndSessionEndpoint field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetEndSessionEndpointOk() (*string, bool) {
	if o == nil || IsNil(o.EndSessionEndpoint) {
		return nil, false
	}
	return o.EndSessionEndpoint, true
}

// HasEndSessionEndpoint returns a boolean if a field has been set.
func (o *OidcConfiguration) HasEndSessionEndpoint() bool {
	if o != nil && !IsNil(o.EndSessionEndpoint) {
		return true
	}

	return false
}

// SetEndSessionEndpoint gets a reference to the given string and assigns it to the EndSessionEndpoint field.
func (o *OidcConfiguration) SetEndSessionEndpoint(v string) {
	o.EndSessionEndpoint = &v
}

// GetFrontchannelLogoutSessionSupported returns the FrontchannelLogoutSessionSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetFrontchannelLogoutSessionSupported() bool {
	if o == nil || IsNil(o.FrontchannelLogoutSessionSupported) {
		var ret bool
		return ret
	}
	return *o.FrontchannelLogoutSessionSupported
}

// GetFrontchannelLogoutSessionSupportedOk returns a tuple with the FrontchannelLogoutSessionSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetFrontchannelLogoutSessionSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.FrontchannelLogoutSessionSupported) {
		return nil, false
	}
	return o.FrontchannelLogoutSessionSupported, true
}

// HasFrontchannelLogoutSessionSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasFrontchannelLogoutSessionSupported() bool {
	if o != nil && !IsNil(o.FrontchannelLogoutSessionSupported) {
		return true
	}

	return false
}

// SetFrontchannelLogoutSessionSupported gets a reference to the given bool and assigns it to the FrontchannelLogoutSessionSupported field.
func (o *OidcConfiguration) SetFrontchannelLogoutSessionSupported(v bool) {
	o.FrontchannelLogoutSessionSupported = &v
}

// GetFrontchannelLogoutSupported returns the FrontchannelLogoutSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetFrontchannelLogoutSupported() bool {
	if o == nil || IsNil(o.FrontchannelLogoutSupported) {
		var ret bool
		return ret
	}
	return *o.FrontchannelLogoutSupported
}

// GetFrontchannelLogoutSupportedOk returns a tuple with the FrontchannelLogoutSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetFrontchannelLogoutSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.FrontchannelLogoutSupported) {
		return nil, false
	}
	return o.FrontchannelLogoutSupported, true
}

// HasFrontchannelLogoutSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasFrontchannelLogoutSupported() bool {
	if o != nil && !IsNil(o.FrontchannelLogoutSupported) {
		return true
	}

	return false
}

// SetFrontchannelLogoutSupported gets a reference to the given bool and assigns it to the FrontchannelLogoutSupported field.
func (o *OidcConfiguration) SetFrontchannelLogoutSupported(v bool) {
	o.FrontchannelLogoutSupported = &v
}

// GetGrantTypesSupported returns the GrantTypesSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetGrantTypesSupported() []string {
	if o == nil || IsNil(o.GrantTypesSupported) {
		var ret []string
		return ret
	}
	return o.GrantTypesSupported
}

// GetGrantTypesSupportedOk returns a tuple with the GrantTypesSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetGrantTypesSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.GrantTypesSupported) {
		return nil, false
	}
	return o.GrantTypesSupported, true
}

// HasGrantTypesSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasGrantTypesSupported() bool {
	if o != nil && !IsNil(o.GrantTypesSupported) {
		return true
	}

	return false
}

// SetGrantTypesSupported gets a reference to the given []string and assigns it to the GrantTypesSupported field.
func (o *OidcConfiguration) SetGrantTypesSupported(v []string) {
	o.GrantTypesSupported = v
}

// GetIdTokenSignedResponseAlg returns the IdTokenSignedResponseAlg field value
func (o *OidcConfiguration) GetIdTokenSignedResponseAlg() []string {
	if o == nil {
		var ret []string
		return ret
	}

	return o.IdTokenSignedResponseAlg
}

// GetIdTokenSignedResponseAlgOk returns a tuple with the IdTokenSignedResponseAlg field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetIdTokenSignedResponseAlgOk() ([]string, bool) {
	if o == nil {
		return nil, false
	}
	return o.IdTokenSignedResponseAlg, true
}

// SetIdTokenSignedResponseAlg sets field value
func (o *OidcConfiguration) SetIdTokenSignedResponseAlg(v []string) {
	o.IdTokenSignedResponseAlg = v
}

// GetIdTokenSigningAlgValuesSupported returns the IdTokenSigningAlgValuesSupported field value
func (o *OidcConfiguration) GetIdTokenSigningAlgValuesSupported() []string {
	if o == nil {
		var ret []string
		return ret
	}

	return o.IdTokenSigningAlgValuesSupported
}

// GetIdTokenSigningAlgValuesSupportedOk returns a tuple with the IdTokenSigningAlgValuesSupported field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetIdTokenSigningAlgValuesSupportedOk() ([]string, bool) {
	if o == nil {
		return nil, false
	}
	return o.IdTokenSigningAlgValuesSupported, true
}

// SetIdTokenSigningAlgValuesSupported sets field value
func (o *OidcConfiguration) SetIdTokenSigningAlgValuesSupported(v []string) {
	o.IdTokenSigningAlgValuesSupported = v
}

// GetIssuer returns the Issuer field value
func (o *OidcConfiguration) GetIssuer() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.Issuer
}

// GetIssuerOk returns a tuple with the Issuer field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetIssuerOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Issuer, true
}

// SetIssuer sets field value
func (o *OidcConfiguration) SetIssuer(v string) {
	o.Issuer = v
}

// GetJwksUri returns the JwksUri field value
func (o *OidcConfiguration) GetJwksUri() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.JwksUri
}

// GetJwksUriOk returns a tuple with the JwksUri field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetJwksUriOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.JwksUri, true
}

// SetJwksUri sets field value
func (o *OidcConfiguration) SetJwksUri(v string) {
	o.JwksUri = v
}

// GetRegistrationEndpoint returns the RegistrationEndpoint field value if set, zero value otherwise.
func (o *OidcConfiguration) GetRegistrationEndpoint() string {
	if o == nil || IsNil(o.RegistrationEndpoint) {
		var ret string
		return ret
	}
	return *o.RegistrationEndpoint
}

// GetRegistrationEndpointOk returns a tuple with the RegistrationEndpoint field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetRegistrationEndpointOk() (*string, bool) {
	if o == nil || IsNil(o.RegistrationEndpoint) {
		return nil, false
	}
	return o.RegistrationEndpoint, true
}

// HasRegistrationEndpoint returns a boolean if a field has been set.
func (o *OidcConfiguration) HasRegistrationEndpoint() bool {
	if o != nil && !IsNil(o.RegistrationEndpoint) {
		return true
	}

	return false
}

// SetRegistrationEndpoint gets a reference to the given string and assigns it to the RegistrationEndpoint field.
func (o *OidcConfiguration) SetRegistrationEndpoint(v string) {
	o.RegistrationEndpoint = &v
}

// GetRequestObjectSigningAlgValuesSupported returns the RequestObjectSigningAlgValuesSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetRequestObjectSigningAlgValuesSupported() []string {
	if o == nil || IsNil(o.RequestObjectSigningAlgValuesSupported) {
		var ret []string
		return ret
	}
	return o.RequestObjectSigningAlgValuesSupported
}

// GetRequestObjectSigningAlgValuesSupportedOk returns a tuple with the RequestObjectSigningAlgValuesSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetRequestObjectSigningAlgValuesSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.RequestObjectSigningAlgValuesSupported) {
		return nil, false
	}
	return o.RequestObjectSigningAlgValuesSupported, true
}

// HasRequestObjectSigningAlgValuesSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasRequestObjectSigningAlgValuesSupported() bool {
	if o != nil && !IsNil(o.RequestObjectSigningAlgValuesSupported) {
		return true
	}

	return false
}

// SetRequestObjectSigningAlgValuesSupported gets a reference to the given []string and assigns it to the RequestObjectSigningAlgValuesSupported field.
func (o *OidcConfiguration) SetRequestObjectSigningAlgValuesSupported(v []string) {
	o.RequestObjectSigningAlgValuesSupported = v
}

// GetRequestParameterSupported returns the RequestParameterSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetRequestParameterSupported() bool {
	if o == nil || IsNil(o.RequestParameterSupported) {
		var ret bool
		return ret
	}
	return *o.RequestParameterSupported
}

// GetRequestParameterSupportedOk returns a tuple with the RequestParameterSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetRequestParameterSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.RequestParameterSupported) {
		return nil, false
	}
	return o.RequestParameterSupported, true
}

// HasRequestParameterSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasRequestParameterSupported() bool {
	if o != nil && !IsNil(o.RequestParameterSupported) {
		return true
	}

	return false
}

// SetRequestParameterSupported gets a reference to the given bool and assigns it to the RequestParameterSupported field.
func (o *OidcConfiguration) SetRequestParameterSupported(v bool) {
	o.RequestParameterSupported = &v
}

// GetRequestUriParameterSupported returns the RequestUriParameterSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetRequestUriParameterSupported() bool {
	if o == nil || IsNil(o.RequestUriParameterSupported) {
		var ret bool
		return ret
	}
	return *o.RequestUriParameterSupported
}

// GetRequestUriParameterSupportedOk returns a tuple with the RequestUriParameterSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetRequestUriParameterSupportedOk() (*bool, bool) {
	if o == nil || IsNil(o.RequestUriParameterSupported) {
		return nil, false
	}
	return o.RequestUriParameterSupported, true
}

// HasRequestUriParameterSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasRequestUriParameterSupported() bool {
	if o != nil && !IsNil(o.RequestUriParameterSupported) {
		return true
	}

	return false
}

// SetRequestUriParameterSupported gets a reference to the given bool and assigns it to the RequestUriParameterSupported field.
func (o *OidcConfiguration) SetRequestUriParameterSupported(v bool) {
	o.RequestUriParameterSupported = &v
}

// GetRequireRequestUriRegistration returns the RequireRequestUriRegistration field value if set, zero value otherwise.
func (o *OidcConfiguration) GetRequireRequestUriRegistration() bool {
	if o == nil || IsNil(o.RequireRequestUriRegistration) {
		var ret bool
		return ret
	}
	return *o.RequireRequestUriRegistration
}

// GetRequireRequestUriRegistrationOk returns a tuple with the RequireRequestUriRegistration field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetRequireRequestUriRegistrationOk() (*bool, bool) {
	if o == nil || IsNil(o.RequireRequestUriRegistration) {
		return nil, false
	}
	return o.RequireRequestUriRegistration, true
}

// HasRequireRequestUriRegistration returns a boolean if a field has been set.
func (o *OidcConfiguration) HasRequireRequestUriRegistration() bool {
	if o != nil && !IsNil(o.RequireRequestUriRegistration) {
		return true
	}

	return false
}

// SetRequireRequestUriRegistration gets a reference to the given bool and assigns it to the RequireRequestUriRegistration field.
func (o *OidcConfiguration) SetRequireRequestUriRegistration(v bool) {
	o.RequireRequestUriRegistration = &v
}

// GetResponseModesSupported returns the ResponseModesSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetResponseModesSupported() []string {
	if o == nil || IsNil(o.ResponseModesSupported) {
		var ret []string
		return ret
	}
	return o.ResponseModesSupported
}

// GetResponseModesSupportedOk returns a tuple with the ResponseModesSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetResponseModesSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.ResponseModesSupported) {
		return nil, false
	}
	return o.ResponseModesSupported, true
}

// HasResponseModesSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasResponseModesSupported() bool {
	if o != nil && !IsNil(o.ResponseModesSupported) {
		return true
	}

	return false
}

// SetResponseModesSupported gets a reference to the given []string and assigns it to the ResponseModesSupported field.
func (o *OidcConfiguration) SetResponseModesSupported(v []string) {
	o.ResponseModesSupported = v
}

// GetResponseTypesSupported returns the ResponseTypesSupported field value
func (o *OidcConfiguration) GetResponseTypesSupported() []string {
	if o == nil {
		var ret []string
		return ret
	}

	return o.ResponseTypesSupported
}

// GetResponseTypesSupportedOk returns a tuple with the ResponseTypesSupported field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetResponseTypesSupportedOk() ([]string, bool) {
	if o == nil {
		return nil, false
	}
	return o.ResponseTypesSupported, true
}

// SetResponseTypesSupported sets field value
func (o *OidcConfiguration) SetResponseTypesSupported(v []string) {
	o.ResponseTypesSupported = v
}

// GetRevocationEndpoint returns the RevocationEndpoint field value if set, zero value otherwise.
func (o *OidcConfiguration) GetRevocationEndpoint() string {
	if o == nil || IsNil(o.RevocationEndpoint) {
		var ret string
		return ret
	}
	return *o.RevocationEndpoint
}

// GetRevocationEndpointOk returns a tuple with the RevocationEndpoint field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetRevocationEndpointOk() (*string, bool) {
	if o == nil || IsNil(o.RevocationEndpoint) {
		return nil, false
	}
	return o.RevocationEndpoint, true
}

// HasRevocationEndpoint returns a boolean if a field has been set.
func (o *OidcConfiguration) HasRevocationEndpoint() bool {
	if o != nil && !IsNil(o.RevocationEndpoint) {
		return true
	}

	return false
}

// SetRevocationEndpoint gets a reference to the given string and assigns it to the RevocationEndpoint field.
func (o *OidcConfiguration) SetRevocationEndpoint(v string) {
	o.RevocationEndpoint = &v
}

// GetScopesSupported returns the ScopesSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetScopesSupported() []string {
	if o == nil || IsNil(o.ScopesSupported) {
		var ret []string
		return ret
	}
	return o.ScopesSupported
}

// GetScopesSupportedOk returns a tuple with the ScopesSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetScopesSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.ScopesSupported) {
		return nil, false
	}
	return o.ScopesSupported, true
}

// HasScopesSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasScopesSupported() bool {
	if o != nil && !IsNil(o.ScopesSupported) {
		return true
	}

	return false
}

// SetScopesSupported gets a reference to the given []string and assigns it to the ScopesSupported field.
func (o *OidcConfiguration) SetScopesSupported(v []string) {
	o.ScopesSupported = v
}

// GetSubjectTypesSupported returns the SubjectTypesSupported field value
func (o *OidcConfiguration) GetSubjectTypesSupported() []string {
	if o == nil {
		var ret []string
		return ret
	}

	return o.SubjectTypesSupported
}

// GetSubjectTypesSupportedOk returns a tuple with the SubjectTypesSupported field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetSubjectTypesSupportedOk() ([]string, bool) {
	if o == nil {
		return nil, false
	}
	return o.SubjectTypesSupported, true
}

// SetSubjectTypesSupported sets field value
func (o *OidcConfiguration) SetSubjectTypesSupported(v []string) {
	o.SubjectTypesSupported = v
}

// GetTokenEndpoint returns the TokenEndpoint field value
func (o *OidcConfiguration) GetTokenEndpoint() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.TokenEndpoint
}

// GetTokenEndpointOk returns a tuple with the TokenEndpoint field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetTokenEndpointOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.TokenEndpoint, true
}

// SetTokenEndpoint sets field value
func (o *OidcConfiguration) SetTokenEndpoint(v string) {
	o.TokenEndpoint = v
}

// GetTokenEndpointAuthMethodsSupported returns the TokenEndpointAuthMethodsSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetTokenEndpointAuthMethodsSupported() []string {
	if o == nil || IsNil(o.TokenEndpointAuthMethodsSupported) {
		var ret []string
		return ret
	}
	return o.TokenEndpointAuthMethodsSupported
}

// GetTokenEndpointAuthMethodsSupportedOk returns a tuple with the TokenEndpointAuthMethodsSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetTokenEndpointAuthMethodsSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.TokenEndpointAuthMethodsSupported) {
		return nil, false
	}
	return o.TokenEndpointAuthMethodsSupported, true
}

// HasTokenEndpointAuthMethodsSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasTokenEndpointAuthMethodsSupported() bool {
	if o != nil && !IsNil(o.TokenEndpointAuthMethodsSupported) {
		return true
	}

	return false
}

// SetTokenEndpointAuthMethodsSupported gets a reference to the given []string and assigns it to the TokenEndpointAuthMethodsSupported field.
func (o *OidcConfiguration) SetTokenEndpointAuthMethodsSupported(v []string) {
	o.TokenEndpointAuthMethodsSupported = v
}

// GetUserinfoEndpoint returns the UserinfoEndpoint field value if set, zero value otherwise.
func (o *OidcConfiguration) GetUserinfoEndpoint() string {
	if o == nil || IsNil(o.UserinfoEndpoint) {
		var ret string
		return ret
	}
	return *o.UserinfoEndpoint
}

// GetUserinfoEndpointOk returns a tuple with the UserinfoEndpoint field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetUserinfoEndpointOk() (*string, bool) {
	if o == nil || IsNil(o.UserinfoEndpoint) {
		return nil, false
	}
	return o.UserinfoEndpoint, true
}

// HasUserinfoEndpoint returns a boolean if a field has been set.
func (o *OidcConfiguration) HasUserinfoEndpoint() bool {
	if o != nil && !IsNil(o.UserinfoEndpoint) {
		return true
	}

	return false
}

// SetUserinfoEndpoint gets a reference to the given string and assigns it to the UserinfoEndpoint field.
func (o *OidcConfiguration) SetUserinfoEndpoint(v string) {
	o.UserinfoEndpoint = &v
}

// GetUserinfoSignedResponseAlg returns the UserinfoSignedResponseAlg field value
func (o *OidcConfiguration) GetUserinfoSignedResponseAlg() []string {
	if o == nil {
		var ret []string
		return ret
	}

	return o.UserinfoSignedResponseAlg
}

// GetUserinfoSignedResponseAlgOk returns a tuple with the UserinfoSignedResponseAlg field value
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetUserinfoSignedResponseAlgOk() ([]string, bool) {
	if o == nil {
		return nil, false
	}
	return o.UserinfoSignedResponseAlg, true
}

// SetUserinfoSignedResponseAlg sets field value
func (o *OidcConfiguration) SetUserinfoSignedResponseAlg(v []string) {
	o.UserinfoSignedResponseAlg = v
}

// GetUserinfoSigningAlgValuesSupported returns the UserinfoSigningAlgValuesSupported field value if set, zero value otherwise.
func (o *OidcConfiguration) GetUserinfoSigningAlgValuesSupported() []string {
	if o == nil || IsNil(o.UserinfoSigningAlgValuesSupported) {
		var ret []string
		return ret
	}
	return o.UserinfoSigningAlgValuesSupported
}

// GetUserinfoSigningAlgValuesSupportedOk returns a tuple with the UserinfoSigningAlgValuesSupported field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *OidcConfiguration) GetUserinfoSigningAlgValuesSupportedOk() ([]string, bool) {
	if o == nil || IsNil(o.UserinfoSigningAlgValuesSupported) {
		return nil, false
	}
	return o.UserinfoSigningAlgValuesSupported, true
}

// HasUserinfoSigningAlgValuesSupported returns a boolean if a field has been set.
func (o *OidcConfiguration) HasUserinfoSigningAlgValuesSupported() bool {
	if o != nil && !IsNil(o.UserinfoSigningAlgValuesSupported) {
		return true
	}

	return false
}

// SetUserinfoSigningAlgValuesSupported gets a reference to the given []string and assigns it to the UserinfoSigningAlgValuesSupported field.
func (o *OidcConfiguration) SetUserinfoSigningAlgValuesSupported(v []string) {
	o.UserinfoSigningAlgValuesSupported = v
}

func (o OidcConfiguration) MarshalJSON() ([]byte, error) {
	toSerialize,err := o.ToMap()
	if err != nil {
		return []byte{}, err
	}
	return json.Marshal(toSerialize)
}

func (o OidcConfiguration) ToMap() (map[string]interface{}, error) {
	toSerialize := map[string]interface{}{}
	toSerialize["authorization_endpoint"] = o.AuthorizationEndpoint
	if !IsNil(o.BackchannelLogoutSessionSupported) {
		toSerialize["backchannel_logout_session_supported"] = o.BackchannelLogoutSessionSupported
	}
	if !IsNil(o.BackchannelLogoutSupported) {
		toSerialize["backchannel_logout_supported"] = o.BackchannelLogoutSupported
	}
	if !IsNil(o.ClaimsParameterSupported) {
		toSerialize["claims_parameter_supported"] = o.ClaimsParameterSupported
	}
	if !IsNil(o.ClaimsSupported) {
		toSerialize["claims_supported"] = o.ClaimsSupported
	}
	if !IsNil(o.CodeChallengeMethodsSupported) {
		toSerialize["code_challenge_methods_supported"] = o.CodeChallengeMethodsSupported
	}
	if !IsNil(o.CredentialsEndpointDraft00) {
		toSerialize["credentials_endpoint_draft_00"] = o.CredentialsEndpointDraft00
	}
	if !IsNil(o.CredentialsSupportedDraft00) {
		toSerialize["credentials_supported_draft_00"] = o.CredentialsSupportedDraft00
	}
	if !IsNil(o.EndSessionEndpoint) {
		toSerialize["end_session_endpoint"] = o.EndSessionEndpoint
	}
	if !IsNil(o.FrontchannelLogoutSessionSupported) {
		toSerialize["frontchannel_logout_session_supported"] = o.FrontchannelLogoutSessionSupported
	}
	if !IsNil(o.FrontchannelLogoutSupported) {
		toSerialize["frontchannel_logout_supported"] = o.FrontchannelLogoutSupported
	}
	if !IsNil(o.GrantTypesSupported) {
		toSerialize["grant_types_supported"] = o.GrantTypesSupported
	}
	toSerialize["id_token_signed_response_alg"] = o.IdTokenSignedResponseAlg
	toSerialize["id_token_signing_alg_values_supported"] = o.IdTokenSigningAlgValuesSupported
	toSerialize["issuer"] = o.Issuer
	toSerialize["jwks_uri"] = o.JwksUri
	if !IsNil(o.RegistrationEndpoint) {
		toSerialize["registration_endpoint"] = o.RegistrationEndpoint
	}
	if !IsNil(o.RequestObjectSigningAlgValuesSupported) {
		toSerialize["request_object_signing_alg_values_supported"] = o.RequestObjectSigningAlgValuesSupported
	}
	if !IsNil(o.RequestParameterSupported) {
		toSerialize["request_parameter_supported"] = o.RequestParameterSupported
	}
	if !IsNil(o.RequestUriParameterSupported) {
		toSerialize["request_uri_parameter_supported"] = o.RequestUriParameterSupported
	}
	if !IsNil(o.RequireRequestUriRegistration) {
		toSerialize["require_request_uri_registration"] = o.RequireRequestUriRegistration
	}
	if !IsNil(o.ResponseModesSupported) {
		toSerialize["response_modes_supported"] = o.ResponseModesSupported
	}
	toSerialize["response_types_supported"] = o.ResponseTypesSupported
	if !IsNil(o.RevocationEndpoint) {
		toSerialize["revocation_endpoint"] = o.RevocationEndpoint
	}
	if !IsNil(o.ScopesSupported) {
		toSerialize["scopes_supported"] = o.ScopesSupported
	}
	toSerialize["subject_types_supported"] = o.SubjectTypesSupported
	toSerialize["token_endpoint"] = o.TokenEndpoint
	if !IsNil(o.TokenEndpointAuthMethodsSupported) {
		toSerialize["token_endpoint_auth_methods_supported"] = o.TokenEndpointAuthMethodsSupported
	}
	if !IsNil(o.UserinfoEndpoint) {
		toSerialize["userinfo_endpoint"] = o.UserinfoEndpoint
	}
	toSerialize["userinfo_signed_response_alg"] = o.UserinfoSignedResponseAlg
	if !IsNil(o.UserinfoSigningAlgValuesSupported) {
		toSerialize["userinfo_signing_alg_values_supported"] = o.UserinfoSigningAlgValuesSupported
	}

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}

	return toSerialize, nil
}

func (o *OidcConfiguration) UnmarshalJSON(bytes []byte) (err error) {
    // This validates that all required properties are included in the JSON object
	// by unmarshalling the object into a generic map with string keys and checking
	// that every required field exists as a key in the generic map.
	requiredProperties := []string{
		"authorization_endpoint",
		"id_token_signed_response_alg",
		"id_token_signing_alg_values_supported",
		"issuer",
		"jwks_uri",
		"response_types_supported",
		"subject_types_supported",
		"token_endpoint",
		"userinfo_signed_response_alg",
	}

	allProperties := make(map[string]interface{})

	err = json.Unmarshal(bytes, &allProperties)

	if err != nil {
		return err;
	}

	for _, requiredProperty := range(requiredProperties) {
		if _, exists := allProperties[requiredProperty]; !exists {
			return fmt.Errorf("no value given for required property %v", requiredProperty)
		}
	}

	varOidcConfiguration := _OidcConfiguration{}

	err = json.Unmarshal(bytes, &varOidcConfiguration)

	if err != nil {
		return err
	}

	*o = OidcConfiguration(varOidcConfiguration)

	additionalProperties := make(map[string]interface{})

	if err = json.Unmarshal(bytes, &additionalProperties); err == nil {
		delete(additionalProperties, "authorization_endpoint")
		delete(additionalProperties, "backchannel_logout_session_supported")
		delete(additionalProperties, "backchannel_logout_supported")
		delete(additionalProperties, "claims_parameter_supported")
		delete(additionalProperties, "claims_supported")
		delete(additionalProperties, "code_challenge_methods_supported")
		delete(additionalProperties, "credentials_endpoint_draft_00")
		delete(additionalProperties, "credentials_supported_draft_00")
		delete(additionalProperties, "end_session_endpoint")
		delete(additionalProperties, "frontchannel_logout_session_supported")
		delete(additionalProperties, "frontchannel_logout_supported")
		delete(additionalProperties, "grant_types_supported")
		delete(additionalProperties, "id_token_signed_response_alg")
		delete(additionalProperties, "id_token_signing_alg_values_supported")
		delete(additionalProperties, "issuer")
		delete(additionalProperties, "jwks_uri")
		delete(additionalProperties, "registration_endpoint")
		delete(additionalProperties, "request_object_signing_alg_values_supported")
		delete(additionalProperties, "request_parameter_supported")
		delete(additionalProperties, "request_uri_parameter_supported")
		delete(additionalProperties, "require_request_uri_registration")
		delete(additionalProperties, "response_modes_supported")
		delete(additionalProperties, "response_types_supported")
		delete(additionalProperties, "revocation_endpoint")
		delete(additionalProperties, "scopes_supported")
		delete(additionalProperties, "subject_types_supported")
		delete(additionalProperties, "token_endpoint")
		delete(additionalProperties, "token_endpoint_auth_methods_supported")
		delete(additionalProperties, "userinfo_endpoint")
		delete(additionalProperties, "userinfo_signed_response_alg")
		delete(additionalProperties, "userinfo_signing_alg_values_supported")
		o.AdditionalProperties = additionalProperties
	}

	return err
}

type NullableOidcConfiguration struct {
	value *OidcConfiguration
	isSet bool
}

func (v NullableOidcConfiguration) Get() *OidcConfiguration {
	return v.value
}

func (v *NullableOidcConfiguration) Set(val *OidcConfiguration) {
	v.value = val
	v.isSet = true
}

func (v NullableOidcConfiguration) IsSet() bool {
	return v.isSet
}

func (v *NullableOidcConfiguration) Unset() {
	v.value = nil
	v.isSet = false
}

func NewNullableOidcConfiguration(val *OidcConfiguration) *NullableOidcConfiguration {
	return &NullableOidcConfiguration{value: val, isSet: true}
}

func (v NullableOidcConfiguration) MarshalJSON() ([]byte, error) {
	return json.Marshal(v.value)
}

func (v *NullableOidcConfiguration) UnmarshalJSON(src []byte) error {
	v.isSet = true
	return json.Unmarshal(src, &v.value)
}


